[Spark-jupyter][1]
- `pip install toree`
- `jupyter toree install --spark_home=/Users/yuanjie/Desktop/intelpython3/lib/python3.7/site-packages/pyspark`


---
[1]: https://blog.csdn.net/qq_24452475/article/details/79838373